@@ -1,6 +1,6 @@
 from uuid import uuid4
 
-from flask import Blueprint, current_app, g, redirect, request, jsonify
+from flask import Blueprint, current_app, g, jsonify, redirect, request
 from rq import Connection, Queue
 
 from .build import build
@@ -41,6 +41,72 @@ def api_latest():
     return redirect("/json/v1/latest.json")
 
 
+def api_v1_stats_targets(branch="SNAPSHOT"):
+    if branch not in current_app.config["BRANCHES"]:
+        return "", 404
+
+    return jsonify(
+        {
+            "branch": branch,
+            "targets": [
+                (s, p.decode("utf-8"))
+                for p, s in get_redis().zrange(
+                    f"stats-targets-{branch}", 0, -1, withscores=True
+                )
+            ],
+        }
+    )
+
+
+@bp.route("/v1/stats/targets/")
+def api_v1_stats_targets_default():
+    return redirect("/api/v1/stats/targets/SNAPSHOT")
+
+
+def api_v1_stats_packages(branch="SNAPSHOT"):
+    if branch not in current_app.config["BRANCHES"]:
+        return "", 404
+
+    return jsonify(
+        {
+            "branch": branch,
+            "packages": [
+                (s, p.decode("utf-8"))
+                for p, s in get_redis().zrange(
+                    f"stats-packages-{branch}", 0, -1, withscores=True
+                )
+            ],
+        }
+    )
+
+
+@bp.route("/v1/stats/packages/")
+def api_v1_stats_packages_default():
+    return redirect("/api/v1/stats/packages/SNAPSHOT")
+
+
+def api_v1_stats_profiles(branch):
+    if branch not in current_app.config["BRANCHES"]:
+        return "", 404
+
+    return jsonify(
+        {
+            "branch": branch,
+            "profiles": [
+                (s, p.decode("utf-8"))
+                for p, s in get_redis().zrange(
+                    f"stats-profiles-{branch}", 0, -1, withscores=True
+                )
+            ],
+        }
+    )
+
+
+@bp.route("/v1/stats/profiles/")
+def api_v1_stats_profiles_default():
+    return redirect("/api/v1/stats/profiles/SNAPSHOT")
+
+
 def get_queue() -> Queue:
     """Return the current queue
 
