@@ -320,4 +320,24 @@ def build(req: dict):
     json_content["id"] = req["profile"]
     json_content.pop("profiles")
 
+    if job:
+        for package in manifest.keys():
+            job.connection.zadd(
+                f"stats-packages-{req['branch_data']['name']}",
+                {package: 1},
+                incr=True,
+            )
+
+        job.connection.zadd(
+            f"stats-profiles-{req['branch_data']['name']}",
+            {req["profile"]: 1},
+            incr=True,
+        )
+
+        job.connection.zadd(
+            f"stats-targets-{req['branch_data']['name']}",
+            {req["target"]: 1},
+            incr=True,
+        )
+
     return json_content
